OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Nedaří se zapisovat do adresáře „config“!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Toto je obvykle možné vyřešit udělením webovému serveru oprávnění k zápisu do adresáře s nastaveními.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ale, pokud chcete mít soubor config.php pouze pro čtení, nastavte  v něm volbu „config_is_read_only“ na hodnotu true.",
    "See %s" : "Viz %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Aplikace %1$s není přítomná nebo její verze není kompatibilní s tímto serverem. Zkontrolujte složku s aplikacemi. ",
    "Sample configuration detected" : "Bylo zjištěno setrvání u předváděcího nastavení",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Pravděpodobně byla zkopírována nastavení ze vzorových souborů. Toto není podporováno a může poškodit vaši instalaci. Před prováděním změn v souboru config.php si přečtěte dokumentaci",
    "The page could not be found on the server." : "Stránka nebyla na serveru nalezena.",
    "%s email verification" : "%s ověřování e-mailem",
    "Email verification" : "Ověřování e-mailem",
    "Click the following button to confirm your email." : "Pokud chcete potvrdit svůj e-mail, klikněte na následující tlačítko.",
    "Click the following link to confirm your email." : "Pokud chcete potvrdit svůj e-mail, klikněte na následující odkaz.",
    "Confirm your email" : "Potvrďte svůj e-mail",
    "Other activities" : "Ostatní aktivity",
    "%1$s and %2$s" : "%1$s a %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s a %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s a %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s a %5$s",
    "Education Edition" : "Vydání pro vzdělávací instituce",
    "Enterprise bundle" : "Sada pro organizace",
    "Groupware bundle" : "Sada pro podporu spolupráce",
    "Hub bundle" : "Sada pro centrum aktivity (hub)",
    "Social sharing bundle" : "Balíček pro sdílení na sociálních sítích",
    "PHP %s or higher is required." : "Je vyžadováno PHP %s nebo novější.",
    "PHP with a version lower than %s is required." : "Je vyžadováno PHP ve verzi starší než %s.",
    "%sbit or higher PHP required." : "Je vyžadováno PHP %sbit nebo vyšší.",
    "The following architectures are supported: %s" : "Jsou podporovány následující architektury: %s",
    "The following databases are supported: %s" : "Jsou podporovány následující databáze: %s",
    "The command line tool %s could not be found" : "Nástroj příkazového řádku %s nebyl nalezen",
    "The library %s is not available." : "Knihovna %s není k dispozici.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Je vyžadována knihovna %1$s novější verze než %2$s – verze k dispozici je %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Je vyžadována knihovna %1$s verzi nižší než %2$s – dostupná verze %3$s.",
    "The following platforms are supported: %s" : "Jsou podporovány následující systémy: %s",
    "Server version %s or higher is required." : "Je potřeba verze serveru %s nebo novější.",
    "Server version %s or lower is required." : "Je potřeba verze serveru %s nebo starší.",
    "Wiping of device %s has started" : "Vymazávání ze zařízení %s zahájeno",
    "Wiping of device »%s« has started" : "Vymazávání ze zařízení „%s“ zahájeno",
    "»%s« started remote wipe" : "„%s“ zahájilo vymazávání na dálku",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Přístroj či aplikace »%s« spustila proces vzdáleného vymazání. Obdržíte další e-mail poté co bude proces ukončen",
    "Wiping of device %s has finished" : "Vymazávání ze zařízení %s dokončeno",
    "Wiping of device »%s« has finished" : "Vymazávání ze zařízení „%s“ dokončeno",
    "»%s« finished remote wipe" : "„%s“ dokončilo vymazání na dálku",
    "Device or application »%s« has finished the remote wipe process." : "Přístroj či aplikace „%s“ dokončila proces vymazání na dálku.",
    "Remote wipe started" : "Vymazání na dálku zahájeno",
    "A remote wipe was started on device %s" : "Na zařízení %s bylo spuštěno vymazání na dálku",
    "Remote wipe finished" : "Vymazání na dálku dokončeno",
    "The remote wipe on %s has finished" : "Vymazání %s na dálku dokončeno",
    "Authentication" : "Ověření",
    "Unknown filetype" : "Neznámý typ souboru",
    "Invalid image" : "Neplatný obrázek",
    "Avatar image is not square" : "Profilový obrázek není čtvercový",
    "Files" : "Soubory",
    "View profile" : "Zobrazit profil ",
    "Local time: %s" : "Místní čas: %s",
    "today" : "dnes",
    "tomorrow" : "zítra",
    "yesterday" : "včera",
    "_in %n day_::_in %n days_" : ["během %n dne","během %n dnů","během %n dnů","během %n dnů"],
    "_%n day ago_::_%n days ago_" : ["včera","před %n dny","před %n dny","před %n dny"],
    "next month" : "následující měsíc",
    "last month" : "minulý měsíc",
    "_in %n month_::_in %n months_" : ["během %n měsíce","během %n měsíců","během %n měsíců","během %n měsíců"],
    "_%n month ago_::_%n months ago_" : ["před %n měsícem","před %n měsíci","před %n měsíci","před %n měsíci"],
    "next year" : "následující rok",
    "last year" : "minulý rok",
    "_in %n year_::_in %n years_" : ["během %n roku","během %n let","během %n let","během %n let"],
    "_%n year ago_::_%n years ago_" : ["před rokem","před %n lety","před %n lety","před %n lety"],
    "_in %n hour_::_in %n hours_" : ["během %n hodiny","během %n hodin","během %n hodin","během %n hodin"],
    "_%n hour ago_::_%n hours ago_" : ["před %n hodinou","před %n hodinami","před %n hodinami","před %n hodinami"],
    "_in %n minute_::_in %n minutes_" : ["během %n minuty","během %n minut","během %n minut","během %n minut"],
    "_%n minute ago_::_%n minutes ago_" : ["před minutou","před %n minutami","před %n minutami","před %n minutami"],
    "in a few seconds" : "během několika sekund",
    "seconds ago" : "před pár sekundami",
    "Empty file" : "Prázdný soubor",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul s identifikátorem: %s neexistuje. Povolte ho v nastavení aplikací, nebo se obraťte na správce.",
    "File already exists" : "Soubor už existuje",
    "Invalid path" : "Neplatný popis umístění",
    "Failed to create file from template" : "Vytvoření souboru ze šablony se nezdařilo",
    "Templates" : "Šablony",
    "File name is a reserved word" : "Název souboru je rezervované slovo",
    "File name contains at least one invalid character" : "Název souboru obsahuje přinejmenším jeden neplatný znak",
    "File name is too long" : "Název souboru je příliš dlouhý",
    "Dot files are not allowed" : "Názvy souborů, začínající na tečku nejsou dovolené",
    "Empty filename is not allowed" : "Je třeba vyplnit název souboru",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Aplikace „%s“ nemůže být nainstalována protože soubor appinfo nelze přečíst.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Aplikaci „%s“ nelze nainstalovat, protože není kompatibilní s touto verzí serveru.",
    "__language_name__" : "Čeština",
    "This is an automatically sent email, please do not reply." : "Toto je automaticky odesílaný e-mail, neodpovídejte na něj.",
    "Appearance and accessibility" : "Vzhled a zpřístupnění",
    "Apps" : "Aplikace",
    "Personal settings" : "Osobní nastavení",
    "Administration settings" : "Nastavení pro správu",
    "Settings" : "Nastavení",
    "Log out" : "Odhlásit se",
    "Users" : "Uživatelé",
    "Email" : "E-mail",
    "Mail %s" : "Poslat e-mail %s",
    "Fediverse" : "Fediverse",
    "View %s on the fediverse" : "Zobrazit %s na fediverse",
    "Phone" : "Telefon",
    "Call %s" : "Zavolat %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Zobrazit %s na Twitteru",
    "Website" : "Webová stránka",
    "Visit %s" : "Navštívit %s",
    "Address" : "Adresa",
    "Profile picture" : "Profilový obrázek",
    "About" : "O uživateli",
    "Display name" : "Zobrazované jméno",
    "Headline" : "Nadpis",
    "Organisation" : "Organizace",
    "Role" : "Role",
    "Additional settings" : "Další nastavení",
    "Enter the database name for %s" : "Zadejte název databáze pro %s",
    "You cannot use dots in the database name %s" : "V názvu databáze %s není možné použít tečky",
    "You need to enter details of an existing account." : "Je třeba zadat podrobnosti existujícího účtu.",
    "Oracle connection could not be established" : "Spojení s Oracle nemohlo být navázáno",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "macOS není podporován a %s nebude na této platformě správně fungovat. Používejte pouze na vlastní nebezpečí!",
    "For the best results, please consider using a GNU/Linux server instead." : "Místo toho zvažte pro nejlepší funkčnost použití GNU/Linux serveru.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Zdá se, že tato instance %s je provozována v 32-bitovém PHP prostředí a v php.ini je nastavena volba open_basedir. Toto povede k problémům se soubory většími než 4 GB a silně není doporučováno.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Odstraňte z php.ini nastavení volby open_basedir nebo přejděte na 64-bitové PHP.",
    "Set an admin password." : "Nastavte heslo pro účet správce.",
    "Cannot create or write into the data directory %s" : "Nedaří se vytvořit nebo zapisovat do datového adresáře %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Je třeba, aby podpůrná vrstva pro sdílení %s implementovala  rozhraní OCP\\Share_Backend",
    "Sharing backend %s not found" : "Podpůrná vrstva pro sdílení %s nenalezena",
    "Sharing backend for %s not found" : "Úložiště sdílení pro %s nenalezeno",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s sdílí „%2$s“ a dodává:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s sdílí „%2$s“ a dodává",
    "»%s« added a note to a file shared with you" : "„%s“ dodává poznámku k nasdílenému souboru ",
    "Open »%s«" : "Otevřít „%s“",
    "%1$s via %2$s" : "%1$s prostřednictvím %2$s",
    "You are not allowed to share %s" : "Nemáte povoleno sdílet %s",
    "Cannot increase permissions of %s" : "Nelze navýšit oprávnění  u %s",
    "Files cannot be shared with delete permissions" : "Soubory nelze sdílet s oprávněními k odstranění",
    "Files cannot be shared with create permissions" : "Soubory nelze sdílet s oprávněními k vytváření",
    "Expiration date is in the past" : "Datum skončení platnosti je v minulosti",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Datum vypršení nelze nastavit na více než %n den do budoucnosti","Datum vypršení nelze nastavit na více než %n dny do budoucnosti","Datum vypršení nelze nastavit na více než %n dnů do budoucnosti","Datum vypršení nelze nastavit na více než %n dny do budoucnosti"],
    "Sharing is only allowed with group members" : "Je povoleno pouze sdílení s členy skupiny",
    "%1$s shared »%2$s« with you" : "%1$s vám sdílí „%2$s“",
    "%1$s shared »%2$s« with you." : "%1$s vám nasdílel(a) „%2$s“.",
    "Click the button below to open it." : "Pro otevření klikněte na tlačítko níže.",
    "The requested share does not exist anymore" : "Požadované sdílení už neexistuje",
    "The requested share comes from a disabled user" : "Požadované sdílení pochází od vypnutého uživatelského účtu",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Uživatel nebyl vytvořen protože bylo dosaženo limitu počtu uživatelů. Více se dozvíte v upozorněních.",
    "Could not find category \"%s\"" : "Nedaří se nalézt kategorii „%s“",
    "Sunday" : "neděle",
    "Monday" : "pondělí",
    "Tuesday" : "úterý",
    "Wednesday" : "středa",
    "Thursday" : "čtvrtek",
    "Friday" : "pátek",
    "Saturday" : "sobota",
    "Sun." : "ne",
    "Mon." : "po",
    "Tue." : "út",
    "Wed." : "st",
    "Thu." : "čt",
    "Fri." : "pá",
    "Sat." : "so",
    "Su" : "ne",
    "Mo" : "po",
    "Tu" : "út",
    "We" : "st",
    "Th" : "čt",
    "Fr" : "pá",
    "Sa" : "so",
    "January" : "leden",
    "February" : "únor",
    "March" : "březen",
    "April" : "duben",
    "May" : "květen",
    "June" : "červen",
    "July" : "červenec",
    "August" : "srpen",
    "September" : "září",
    "October" : "říjen",
    "November" : "listopad",
    "December" : "prosinec",
    "Jan." : "led.",
    "Feb." : "úno.",
    "Mar." : "bře.",
    "Apr." : "dub.",
    "May." : "kvě.",
    "Jun." : "čvn.",
    "Jul." : "čvc.",
    "Aug." : "srp.",
    "Sep." : "zář.",
    "Oct." : "říj.",
    "Nov." : "list.",
    "Dec." : "pro.",
    "A valid password must be provided" : "Je třeba zadat platné heslo",
    "Login canceled by app" : "Přihlášení zrušeno aplikací",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Aplikaci „%1$s“ nelze nainstalovat, protože nejsou splněny následující závislosti: %2$s",
    "a safe home for all your data" : "bezpečný domov pro všechna vaše data",
    "File is currently busy, please try again later" : "Soubor je nyní používán, zkuste to později",
    "Cannot download file" : "Soubor se nedaří stáhnout",
    "Application is not enabled" : "Aplikace není povolena",
    "Authentication error" : "Chyba při ověřování se",
    "Token expired. Please reload page." : "Platnost tokenu skončila. Načtěte stránku znovu.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Nejsou nainstalovány ovladače databází (sqlite, mysql nebo postresql).",
    "Cannot write into \"config\" directory." : "Nedaří se zapisovat do adresáře „config“.",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Toto obvykle lze vyřešit udělením oprávnění k zápisu do kořenové složky webu pro účet, pod kterým je provozován webový server. Viz %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Nebo, pokud chcete mít soubor config.php pouze pro čtení, nastavte v něm volbu „config_is_read_only“ na hodnotu true. Viz %s",
    "Cannot write into \"apps\" directory." : "Nedaří se zapisovat do adresáře „apps“.",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Toto je obvykle možné napravit udělením přístupu ke čtení adresáře s aplikací pro webový server nebo vypnutím katalogu s aplikacemi v souboru s nastaveními.",
    "Cannot create \"data\" directory." : "Nedaří se vytvořit adresář „data“.",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Toto obvykle lze vyřešit udělením oprávnění k zápisu do kořenové složky webu pro účet, pod kterým je provozován webový server. Viz %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Oprávnění lze obvykle napravit umožněním zápisu do kořene webu pro účet, pod kterým je provozován webový server. Viz %s.",
    "Your data directory is not writable." : "Adresář data není přístupný pro zápis.",
    "Setting locale to %s failed." : "Nastavení místních a jazykových nastavení na %s se nezdařilo.",
    "Please install one of these locales on your system and restart your web server." : "Do svého systému nainstalujte alespoň jeden z těchto jazyků a restartujte webový server.",
    "PHP module %s not installed." : "PHP modul %s není nainstalován.",
    "Please ask your server administrator to install the module." : "Požádejte správce serveru, který využíváte o instalaci tohoto modulu.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Hodnota v konfiguraci PHP „%s“ není nastavená na „%s“.",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Úprava tohoto nastavení v php.ini umožní Nextcloud opět zprovoznit",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> je nastaveno na <code>%s</code> namísto očekávané hodnoty <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Pro nápravu nastavte v souboru php.ini parametr <code>mbstring.func_overload</code> na <code>0</code>.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP je patrně nastaveno tak, aby odstraňovalo bloky komentářů. Toto bude mít za následek znepřístupnění mnoha důležitých aplikací.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Toto je pravděpodobně způsobeno aplikacemi pro urychlení načítání jako jsou Zend OPcache nebo eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP moduly jsou nainstalovány, přesto jsou uváděny jako chybějící?",
    "Please ask your server administrator to restart the web server." : "Požádejte správce serveru, který využíváte o restart webového serveru.",
    "The required %s config variable is not configured in the config.php file." : "Požadovaná proměnná nastavení %s není v souboru s nastaveními config.php nastavena.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Požádejte správce serveru, který využíváte, aby zkontroloval nastavení serveru.",
    "Your data directory must be an absolute path." : "Je třeba, aby váš adresář data byl zadán jako úplný popis umístění.",
    "Check the value of \"datadirectory\" in your configuration." : "Zkontrolujte hodnotu „datadirectory“ ve svém nastavení.",
    "Your data directory is invalid." : "Váš adresář data není platný.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Ověřte, že v kořeni datového adresáře je soubor s názvem „.ocdata“.",
    "Action \"%s\" not supported or implemented." : "Akce „%s“ není podporována nebo implementována.",
    "Authentication failed, wrong token or provider ID given" : "Ověření se nezdařilo, předán chybný token nebo identifikátor poskytovatele",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Pro dokončení požadavku chybí parametry. Konkrétně: „%s“",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "Identifikátor „%1$s“ už je používán poskytovatelem federování cloudu „%2$s“",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Poskytovatel federování cloudů s identifikátorem: „%s“ neexistuje",
    "Could not obtain lock type %d on \"%s\"." : "Nedaří získat zámek typu %d na „%s“.",
    "Storage unauthorized. %s" : "Úložiště neověřeno. %s",
    "Storage incomplete configuration. %s" : "Neúplné nastavení pro úložiště. %s",
    "Storage connection error. %s" : "Chyba připojení úložiště. %s",
    "Storage is temporarily not available" : "Úložiště je dočasně nedostupné",
    "Storage connection timeout. %s" : "Překročen časový limit připojování k úložišti. %s",
    "Free prompt" : "Prompt zdarma",
    "Runs an arbitrary prompt through the language model." : "Spouští libovolnou výzvu skrze jazykový model.",
    "Generate headline" : "Vytvořit nadpis",
    "Generates a possible headline for a text." : "Vytvoří možný nadpis pro text.",
    "Summarize" : "Stručný souhrn",
    "Summarizes text by reducing its length without losing key information." : "Vytvoří stručný souhrn textu tím, že zkrátí jeho délku aniž by byly ztraceny klíčové informace",
    "Extract topics" : "Vyzískat témata",
    "Extracts topics from a text and outputs them separated by commas." : "Vyzíská témata z textu a vypíše je oddělované čárkami.",
    "404" : "404",
    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Aby mohl přistupovat k tomuto nastavení je třeba, aby přihlášený uživatel byl správce, dílčí správce nebo obdržel speciální oprávnění",
    "Logged in user must be an admin or sub admin" : "Je třeba, aby přihlášený uživatel byl správcem či správcem pro dílčí oblast",
    "Logged in user must be an admin" : "Je třeba, aby přihlášený uživatel byl správce",
    "Help" : "Nápověda",
    "Unknown user" : "Neznámý uživatel",
    "Enter the database username and name for %s" : "Zadejte uživatelské jméno v databázi a název pro %s",
    "Enter the database username for %s" : "Zadejte uživatelské jméno v databázi pro %s",
    "MySQL username and/or password not valid" : "Neplatné uživatelské jméno a/nebo heslo do MySQL",
    "Oracle username and/or password not valid" : "Neplatné uživatelské jméno a/nebo heslo do Oracle",
    "PostgreSQL username and/or password not valid" : "Neplatné uživatelské jméno a/nebo heslo do PostgreSQL",
    "Set an admin username." : "Nastavte uživatelské jméno správce.",
    "Sharing %s failed, because this item is already shared with user %s" : "Sdílení %s se nezdařilo, protože tato položka už je sdílena s uživatelem %s",
    "The username is already being used" : "Uživatelské jméno už je využíváno",
    "Could not create user" : "Nepodařilo se vytvořit uživatele",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Pouze následující znaky jsou povoleny pro uživatelské jméno: „a-z“, „A-Z“, „0-9“, mezery  a „_.@-'“",
    "A valid username must be provided" : "Je třeba zadat platné uživatelské jméno",
    "Username contains whitespace at the beginning or at the end" : "Uživatelské jméno je chybné – na jeho začátku či konci se nachází prázdný znak (mezera, tabulátor, atp.)",
    "Username must not consist of dots only" : "Uživatelské jméno se nemůže skládat pouze ze samých teček",
    "Username is invalid because files already exist for this user" : "Uživatelské jméno není platné, protože protože pro tohoto uživatele už existují soubory",
    "User disabled" : "Uživatel zakázán",
    "PostgreSQL >= 9 required." : "Je vyžadováno PostgreSQL verze 9 a novější.",
    "Please upgrade your database version." : "Aktualizujte verzi vámi využívané databáze.",
    "Your data directory is readable by other users." : "Váš adresář data je čitelný ostatním uživatelům.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Změňte práva na 0770, aby obsah adresáře nemohl být vypisován ostatními uživateli."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
